Class: DBus::Main

Inherits:
Object
  • Object
show all
Defined in:
lib/dbus/bus.rb

Overview

Main event loop class.

Class that takes care of handling message and signal events asynchronously. Note: This is a native implement and therefore does not integrate with a graphical widget set main loop.

Instance Method Summary collapse

Constructor Details

#initializeMain

Create a new main event loop.



703
704
705
# File 'lib/dbus/bus.rb', line 703

def initialize
  @buses = Hash.new
end

Instance Method Details

#<<(bus) ⇒ Object

Add a bus to the list of buses to watch for events.



708
709
710
# File 'lib/dbus/bus.rb', line 708

def <<(bus)
  @buses[bus.socket] = bus
end

#runObject

Run the main loop. This is a blocking call!



713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
# File 'lib/dbus/bus.rb', line 713

def run
  loop do
    ready, dum, dum = IO.select(@buses.keys)
    ready.each do |socket|
      b = @buses[socket]
      begin
        b.update_buffer
      rescue EOFError
        return              # the bus died
      end
      while m = b.pop_message
        b.process(m)
      end
    end
  end
end